import { Component, OnInit, ViewChild } from '@angular/core';
import { Router } from '@angular/router';
import { BryntumSchedulerComponent } from '@bryntum/scheduler-angular';
import { ResourceStore, Scheduler } from '@bryntum/scheduler/scheduler.lite.umd.js';

@Component({
  selector: 'app-planning',
  templateUrl: './planning.component.html',
  styleUrls: ['./planning.component.css']
})
export class PlanningComponent implements OnInit {
  public resourceColumns: any[];
  public resourceStore: ResourceStore;
  private scheduler: Scheduler;
  public eventRenderer: any;

  @ViewChild(BryntumSchedulerComponent, { static: false }) schedulerComponent: BryntumSchedulerComponent;

  constructor(private readonly router: Router) { }

  public ngOnInit(): void {
    this.initResourceColumns();
    this.initResourceStore();
    this.initEventRenderer();
  }

  public ngAfterViewInit(): void {
    this.scheduler = this.schedulerComponent.instance;
    this.scheduler.on('dragCreateEnd', ({ eventRecord }) => {
      void this.router.navigate(
        [`editEvent`],
        {
          queryParams: {
            state: eventRecord,
          },
        },
      );
    });
  }

  private initResourceColumns(): void {
    this.resourceColumns = [
      {
        type: 'tree',
        field: 'name',
        width: 250,
        htmlEncode: false,
      },
    ];
  }

  private initResourceStore(): void {
    this.resourceStore = new ResourceStore({
      tree: true,
      readUrl: `test`,
      headers: {},
    });
    this.resourceStore.rootNode.appendChild([
      {
        id: '44b3b610-b455-48b5-a738-6370cec57cd1',
        name: 'r1',
        children: false,
      },
      {
        id: '745b7453-4a01-4ccc-94a0-15925895f369',
        name: 'r2',
        children: [
          {
            id: 'child1',
            name: 'Child 1',
          },
        ],
      },
      {
        id: 'a20f77cb-506c-4d54-a42d-230a88c49e74',
        name: 'r3',
        expanded: true,
        children: [
          {
            id: 'child2',
            name: 'Child 2',
          },
          {
            id: 'child3',
            name: 'Child 3',
          },
        ],
      },
    ] as any);
  }

  private initEventRenderer(): void {
    this.eventRenderer = () => {
      return `<div>My custom HTML</div>`;
    };
  }
}
